@@ -76,8 +76,12 @@ identifier st t@((Layout,"("):stream) =
           ((Varop,v):_) | not (v`inST`st) -> Just (fix v)
           _             -> Nothing
 identifier st t@((Keyword,"foreign"):stream) = Nothing -- not yet implemented
+identifier st t@((Keyword,"data"):(Space,_):(Keyword,"family"):stream)
+                                             = getConid stream
 identifier st t@((Keyword,"data"):stream)    = getConid stream
 identifier st t@((Keyword,"newtype"):stream) = getConid stream
+identifier st t@((Keyword,"type"):(Space,_):(Keyword,"family"):stream)
+                                             = getConid stream
 identifier st t@((Keyword,"type"):stream)    = getConid stream
 identifier st t@((Keyword,"class"):stream)   = getConid stream
 identifier st t@((Keyword,"instance"):stream)= getInstance stream
